%%
%% This is file `mazovia.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% strony.dtx  (with options: `mazovia')
%% 
%% This is a generated file.
%% 
%% Copyright (C) 1994 by Mariusz Olko.  All rights reserved.
%% Copyright (C) 1997,1998 by Mariusz Olko and Marcin Woli\'nski.
%% Copyright (C) 2000,2002,2003 by Marcin Woli\'nski.
%% 
%% 
%% This file is part of the package `PLaTeX'
%% -----------------------------------------
%% 
%% It may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.2
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%    http://www.latex-project.org/lppl.txt
%% and version 1.2 or later is part of all distributions of LaTeX
%% version 1999/12/01 or later.
%% 
%% This file may only be distributed together with a copy of the PLaTeX
%% package.
%% 
\ProvidesFile{mazovia.def}
\DeclareInputText{143}{\k A}
\DeclareInputText{149}{\@tabacckludge'C}
\DeclareInputText{144}{\k E}
\DeclareInputText{156}{\L}
\DeclareInputText{165}{\@tabacckludge'N}
\DeclareInputText{163}{\@tabacckludge'O}
\DeclareInputText{152}{\@tabacckludge'S}
\DeclareInputText{160}{\@tabacckludge'Z}
\DeclareInputText{161}{\.Z}
\DeclareInputText{134}{\k a}
\DeclareInputText{141}{\@tabacckludge'c}
\DeclareInputText{145}{\k e}
\DeclareInputText{146}{\l}
\DeclareInputText{164}{\@tabacckludge'n}
\DeclareInputText{162}{\@tabacckludge'o}
\DeclareInputText{158}{\@tabacckludge's}
\DeclareInputText{166}{\@tabacckludge'z}
\DeclareInputText{167}{\.z}
\endinput
%%
%% End of file `mazovia.def'.
